@@ -1,6 +1,6 @@
 # todo: Implement logging
 # import logging
-
+__version__ = '1.5.5.1'
 
 class DWProducts:
     Landsat8_USGS = 'L8_USGS'
@@ -8,11 +8,9 @@ class DWProducts:
     Sentinel2_ESA = 'S2_S2COR'
     Sentinel2_L1C = 'S2_L1C'
 
-
 try:
     from osgeo import gdal
     # just imports DWWaterDetect if gdal is present
-    from waterdetect.WaterDetect import DWWaterDetect
 
 except BaseException as error:
     # print(error)
@@ -21,6 +19,19 @@ except BaseException as error:
           'loading satellite images from disk will be possible')
     gdal = None
 
+# Correct the jaccard score name depending on the sklearn version
+from packaging import version
+from sklearn import __version__ as skversion
+
+if version.parse(skversion) < version.parse('0.21'):
+    from sklearn.metrics import jaccard_similarity_score as jaccard_score
+    from sklearn.metrics import calinski_harabaz_score as calinski_harabasz_score
+else:
+    from sklearn.metrics import jaccard_score
+    from sklearn.metrics import calinski_harabasz_score
+
+from waterdetect.WaterDetect import DWWaterDetect
 from waterdetect.Image import DWImageClustering
 from waterdetect.Common import DWutils, DWConfig
 
+
